<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Get info from any web service or page. Contribute to oscarotero/Embed development by creating an account on GitHub.',
    'favicon' => 'https://github.githubassets.com/favicons/favicon.svg',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://avatars.githubusercontent.com/u/377873?s=400&v=4',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'GitHub',
    'providerUrl' => 'https://github.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'oscarotero/Embed',
    'url' => 'https://github.com/oscarotero/Embed/blob/master/composer.json',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
